"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var http_1 = require("../errors/http");
var BaseRouter = /** @class */ (function () {
    function BaseRouter() {
        this.map = {};
    }
    BaseRouter.prototype.getMapKey = function (route, separator) {
        if (separator === void 0) { separator = BaseRouter.separator; }
        return "".concat(route.method.toLowerCase()).concat(separator).concat(route.path);
    };
    BaseRouter.prototype.updateConfig = function (config, basePath) {
        var _this = this;
        var arrayOfRoutes = Array.isArray(config) ? config : [config];
        arrayOfRoutes.forEach(function (route) {
            var _a;
            var controller = route.controller;
            var mapKey = _this.getMapKey(__assign(__assign({}, route), { path: (_a = route.path) !== null && _a !== void 0 ? _a : basePath }));
            _this.map[mapKey] = controller;
        });
    };
    BaseRouter.prototype.usePath = function (path, config) {
        this.updateConfig(config, path);
    };
    BaseRouter.prototype.useController = function (config) {
        this.updateConfig(config);
    };
    /**
     * Overloaded method.
     *
     * It could be called with one parameter a BaseRouterUseType or array of BaseRouterUseType. Path should be specified in the object.
     * It could be called with two parameters: path, and BaseRouterUseType;
     *
     * I keeps this just for backward compatibility.
     *
     * @param args All arguments.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    BaseRouter.prototype.use = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (typeof args[0] === 'string') {
            this.usePath.apply(this, args);
        }
        else {
            this.useController.apply(this, args);
        }
    };
    BaseRouter.prototype.delete = function (awsPath) {
        delete this.map[awsPath];
    };
    BaseRouter.prototype.expose = function () {
        throw http_1.NotImplementedControllerError;
    };
    BaseRouter.errorToHttpError = function (e) {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        var error = http_1.ServerError;
        if ((0, http_1.isHttpError)(e)) {
            error = e;
        }
        var statusCode = error.statusCode, message = error.message;
        return { statusCode: statusCode, body: message };
    };
    BaseRouter.separator = ':::';
    return BaseRouter;
}());
exports.default = BaseRouter;
